@@ -1,4 +1,5 @@
-from setux.util import memo
+from pybrary.func import memo
+
 from setux.logger import debug
 
 
