@@ -1,4 +1,4 @@
-from setux.util import todo
+from pybrary.func import todo
 
 
 class Module:
