@@ -1,5 +1,6 @@
+from pybrary.func import todo
+
 from setux.logger import info
-from setux.util import todo
 from setux.core.manage import Manager
 
 
