@@ -5,6 +5,8 @@ from subprocess import (
     run,
 )
 
+from pybrary.func import todo
+
 from .errors import (
     MissingModuleError,
     AmbiguousModuleNameError,
@@ -12,7 +14,6 @@ from .errors import (
     UnsupportedDistroError,
 )
 from setux.logger import debug, info, error
-from setux.util import todo
 
 from .module import Module
 from .distro import Distro
