@@ -1,5 +1,6 @@
+from pybrary.string import oct_mod
+
 from setux.logger import debug
-from setux.util import oct_mod
 from setux.core.manage import SpecChecker
 
 
